import 'package:equatable/equatable.dart';
import 'package:json_annotation/json_annotation.dart';

part 'ol_author_model.g.dart';

abstract class OLAuthorBase extends Equatable {
  @override
  List<Object?> get props => [];

  const OLAuthorBase();
}

class OLAuthorError extends OLAuthorBase {
  static const message = "Error on returning a valid Author Object";

  @override
  List<Object?> get props => [message];

  @override
  bool? get stringify => false;

  const OLAuthorError();

  @override
  String toString() {
    return 'Error: $message';
  }
}

@JsonSerializable()
class OLAuthor extends OLAuthorBase {
  final String name;
  final String personal_name;

  @override
  List<Object?> get props => [name, personal_name];

  const OLAuthor({
    this.name = "",
    this.personal_name = "",
  });

  factory OLAuthor.fromJson(Map<String, dynamic> json) {
    return _$OLAuthorFromJson(json);
  }

  Map<String, dynamic> toJson() {
    return _$OLAuthorToJson(this);
  }

  @override
  String toString() {
    return '${name.isNotEmpty ? 'name:$name' : ''}${name.isNotEmpty && personal_name.isNotEmpty ? ' ' : ''}${personal_name.isNotEmpty ? 'personal_name:$personal_name' : ''}';
  }
}
